/*
 *                            COPYRIGHT
 *
 *  cschem - modular/flexible schematics editor - tEDAx netlist export
 *  Copyright (C) 2022 Tibor 'Igor2' Palinkas
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 *  Contact:
 *    Project page: http://repo.hu/projects/cschem
 *    lead developer: email to cschem (at) igor2.repo.hu
 *    mailing list: cschem (at) list.repo.hu (send "subscribe")
 */

#include <librnd/core/hid.h>
#include <librnd/core/hid_attrib.h>
#include <librnd/core/hid_nogui.h>
#include <librnd/core/hid_init.h>
#include <sch-rnd/export.h>

static const char tedax_cookie[] = "tEDAx export hid";

static const rnd_export_opt_t tedax_options[] = {
	{"outfile", "Name of the tEDAx netlist output file",
	 RND_HATT_STRING, 0, 0, {0, 0, 0}, 0},
#define HA_outfile 0
};

#define NUM_OPTIONS (sizeof(tedax_options)/sizeof(tedax_options[0]))

static rnd_hid_attr_val_t tedax_values[NUM_OPTIONS];

static const rnd_export_opt_t *tedax_get_export_options(rnd_hid_t *hid, int *n)
{
	const char *val = tedax_values[HA_outfile].str;

#if 0
	csch_sheet_t *sheet = (csch_sheet_t *)csch_hidlib;
	if ((sheet != NULL) && ((val == NULL) || (*val == '\0')))
		pcb_derive_default_filename(sheet->hidlib.filename, &values[HA_outfile], ".tdx");
#endif

	if (n)
		*n = NUM_OPTIONS;
	return tedax_options;
}

static void tedax_do_export(rnd_hid_t *hid, rnd_hid_attr_val_t *options)
{
	const char *filename;

	if (!options) {
		tedax_get_export_options(hid, 0);
		options = tedax_values;
	}

	filename = options[HA_outfile].str;
	if (!filename)
		filename = "sch-rnd-out.tdx";

	sch_rnd_do_export(1, "tedax");
}

static int tedax_usage(rnd_hid_t *hid, const char *topic)
{
	fprintf(stderr, "\ntEDAx exporter command line arguments:\n\n");
	rnd_hid_usage(tedax_options, sizeof(tedax_options) / sizeof(tedax_options[0]));
	fprintf(stderr, "\nUsage: sch-rnd [generic_options] -x tedax [options] foo.sch\n\n");
	return 0;
}


static int tedax_parse_arguments(rnd_hid_t *hid, int *argc, char ***argv)
{
	rnd_export_register_opts2(hid, tedax_options, sizeof(tedax_options) / sizeof(tedax_options[0]), tedax_cookie, 0);
	return rnd_hid_parse_command_line(argc, argv);
}

rnd_hid_t tedax_hid = {0};
